Objects that publish and request strongly-typed data to named topics on the Host
Modules
Structs
- Active
- State marker for a Node capable of manually sending publish/request messages
- Idle
- State marker for a Node that has not been connected to a Host
- Node
- Strongly-typed Node capable of publish/request on Host
- Subscription
- State marker for a Node with an active topic subscription